Name:           bionetgen
Version:        2.2.5
Release:        7%{?dist}
Summary:        Software for rule-based modeling of biochemical systems

License:        GPLv3
URL:            https://code.google.com/p/bionetgen/
Source0:        https://bionetgen.googlecode.com/files/BioNetGen-%{version}-stable.zip

BuildRequires:  muParser-devel >= 2.2.3-6
BuildRequires:  sundials-devel
BuildRequires:  openmpi-devel
BuildRequires:  autoconf automake
BuildRequires:  libtool
Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:       %{name}-perl = %{version}-%{release}

# BioNetGen does not namespace its perl modules
%global __provides_exclude perl\\(.*BNG.*|Cache|CartesianProduct|Compartment.*|Component.*|Console|EnergyPattern|Expression|Function|HNauty|Map|ModelWrapper|Molecule*|Observable|Param*|PatternGraph|Population*|RateLaw|RefineRule|Rxn*|Species*|Transformation*|XML::*|XMLReader\\)
%global __requires_exclude perl\\(.*BNG.*|Cache|CartesianProduct|Compartment.*|Component.*|Console|EnergyPattern|Expression|Function|HNauty|Map|ModelWrapper|Molecule*|Observable|Param*|PatternGraph|Population*|RateLaw|RefineRule|Rxn*|Species*|Transformation*|XML::*|XMLReader\\)

%description
BioNetGen is software for the specification and simulation of
rule-based models of biochemical systems, including signal
transduction, metabolic, and genetic regulatory networks. The
BioNetGen language has recently been extended to include explicit
representation of compartments. A review of methods for rule-based
modeling is available in Science Signaling (Sci. STKE, 18 July 2006,
Issue 344, p. re6).

BioNetGen is presently a mixture of Perl and C++. Network generation
is currently implemented in Perl, the network simulator is C++, and a
new language parser is being developed with ANTLR.

%package perl
Summary:        Perl scripts used by bionetgen
BuildArch:      noarch
Requires:       bionetgen = %{version}-%{release}
%description perl
%{summary}.

%prep
%setup -q -n BioNetGen-%{version}-stable
pushd Network3
sed -i 's/AC_PROG_LIBTOOL/AM_PROG_AR\nLT_INIT/' configure.ac
sed -i 's/cvode-2\.6\.0//; s/muparser_v2_2_3//' configure.ac Makefile.am
sed -i -r 's/(run_network_LDADD =).*/\1 libmathutils.la -lmuparser -lsundials_nvecserial -lsundials_cvode/' src/Makefile.am
rm -rf Network3/cvode-2.6.0 Network3/muparser_v2_2_3

%build
pushd Network3
autoreconf -iv
%_openmpi_load

%configure
make %{?_smp_mflags}

%install
pushd Network3
%make_install
popd
mkdir -vp %{buildroot}/%{perl_vendorlib}/BioNetGen
cp -r Perl2 %{buildroot}/%{perl_vendorlib}/BioNetGen/
cp BNG2.pl %{buildroot}/%{perl_vendorlib}/BioNetGen/

%files
%license LICENSE.txt
%doc CREDITS.txt CHANGES.txt README_FIRST.txt
%{_bindir}/run_network

%files perl
%{perl_vendorlib}/BioNetGen

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jun 05 2015 Jitka Plesnikova <jplesnik@redhat.com> - 2.2.5-6
- Perl 5.22 rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.2.5-5
- Rebuilt for GCC 5 C++11 ABI change

* Tue Mar 31 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.2.5-4
- Rebuilt for sundials 2.6.0.

* Thu Feb 26 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/GCC5 (#1195309)

* Sun Nov 30 2014 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.2.5-2
- Drop dependency on compat f77, it is not needed.

* Fri Nov 21 2014 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.2.5-1
- Initial packaging.
